<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Modo avião ativado</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Modo avião desativado</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Desativar</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Ativar</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Modo Avião</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>Configurações do modo avião</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Modo Avião</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation>Meus Dispositivos </translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Configurações de Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Desligado</translation>
    </message>
    <message>
        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Desativar</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Ativar</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Configurações de Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 conectado</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Conectando...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Desativado</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>Conectado %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Desconectado</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Desligado</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>Brilho</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Configurações de exibição</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>Configurações de exibição</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>Brilho</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>Dom</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>Seg</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>Ter</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>Qua</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>Qui</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>Sex</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>Sáb</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Adicionar layout de teclado</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Data e Hora</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>Formato de 12 horas</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>Formato de 24 horas</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Configurações de data e hora</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Abrir calendário</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Segunda-feira</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Terça-feira</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Quarta-feira</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Quinta-feira</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Sexta-feira</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sábado</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Domingo</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>segunda-feira</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>terça-feira</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>quarta-feira</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>quinta-feira</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>sexta-feira</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>sábado</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>domingo</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation>Outros dispositivos</translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>Modo Não Perturbe</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>Configurações do modo Não Perturbe</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Desativar</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Ativar</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>Modo Não Perturbe ativado</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>Modo Não Perturbe desativado</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>Modo Não Perturbe</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>Conforto ocular</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>Conforto ocular ativado</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>Conforto ocular desativado</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Configurações de exibição</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation>Conforto ocular</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Ligado</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Desligado</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Claro</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Escuro</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation>Desativar conforto ocular</translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation>Ativar conforto ocular</translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation>Configurações de exibição</translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation>Tema: Claro</translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation>Tema: Escuro</translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation>Tema: Automático</translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation>Efeitos visuais</translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation>Claro</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Escuro</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation>Nenhuma mensagem</translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation>Configurações de notificação</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Notificações</translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation>Desativar modo Não Perturbe</translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation>Ativar modo Não Perturbe</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>Notificações</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Teclado Virtual</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation>Alto Desempenho</translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation>Equilibrado</translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation>Economia de energia</translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation>Desempenho Equilibrado</translation>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation>Energia</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>Configurações de energia</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>%1 carregado, %2m restantes</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>%1 carregado, %2h%3m restantes</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Carregando %1, %2m até completar</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Carregando %1, %2h%3 até completar</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>%1 carregado</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Carregando %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>%1 carregado...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>%1 carregado, bateria cheia</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation>%1 carregado, descarregando</translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>Bateria</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation>Carregando, calculando o tempo estimado de carregamento</translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation>Calculando o tempo restante de uso</translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation>%1m restante</translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation>%1h %2m restantes</translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation>Descarregando</translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation>Totalmente carregado</translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation>Carregando, %1m até ficar cheio</translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation>Carregando, %1h%2m até completar</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation>%1 carregado, %2h restantes</translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation>%1h restantes</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation>Carregando %1, %2h até completar</translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation>Carregando, %1h até completar</translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation>Configurações de energia</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>Player de música</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconhecido</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Sair</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Configurações de energia</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Atualizar e desligar</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Atualizar e reiniciar</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Trocar usuário</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation>Hoje</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>Lunar</translation>
    </message>
    <message>
        <source>y</source>
        <translation>a</translation>
    </message>
    <message>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <source>d</source>
        <translation>d</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Segunda-feira</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Terça-feira</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Quarta-feira</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Quinta-feira</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Sexta-feira</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sábado</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Domingo</translation>
    </message>
    <message>
        <source>Jan</source>
        <translation>Jan</translation>
    </message>
    <message>
        <source>Feb</source>
        <translation>Fev</translation>
    </message>
    <message>
        <source>Mar</source>
        <translation>Mar</translation>
    </message>
    <message>
        <source>Apr</source>
        <translation>Abr</translation>
    </message>
    <message>
        <source>May</source>
        <translation>Mai</translation>
    </message>
    <message>
        <source>Jun</source>
        <translation>Jun</translation>
    </message>
    <message>
        <source>Jul</source>
        <translation>Jul</translation>
    </message>
    <message>
        <source>Aug</source>
        <translation>Ago</translation>
    </message>
    <message>
        <source>Sept</source>
        <translation>Set</translation>
    </message>
    <message>
        <source>Oct</source>
        <translation>Out</translation>
    </message>
    <message>
        <source>Nov</source>
        <translation>Nov</translation>
    </message>
    <message>
        <source>Dec</source>
        <translation>Dez</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Abrir calendário</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>segunda-feira</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>terça-feira</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>quarta-feira</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>quinta-feira</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>sexta-feira</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>sábado</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>domingo</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Volume</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Saída</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Configurações de som</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Som</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>Desativar mudo</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Ativar mudo</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Configurações de som</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>Nenhum dispositivo de saída</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Volume %1</translation>
    </message>
</context>
</TS>